@@ -1,12 +1,13 @@
+# $Id: Array.pm 2327 2008-05-21 05:42:02Z rcaputo $
 # Copyrights and documentation are at the end.
 
 package POE::Queue::Array;
 
 use strict;
 
-use vars qw($VERSION @ISA);
-$VERSION = '1.294_512'; # NOTE - Should be #.### (three decimal places)
+use vars qw(@ISA $VERSION);
 @ISA = qw(POE::Queue);
+$VERSION = do {my($r)=(q$Revision: 2327 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Errno qw(ESRCH EPERM);
 use Carp qw(confess);
@@ -107,19 +108,27 @@ sub dequeue_next {
 }
 
 ### Return the next item's priority, undef if the queue is empty.
-# This is POE's most-called method.  We could greatly benefit from
-# finding ways to reduce the number of calls.
+
+# Ton Hospel suggests that assignment is relatively slow.  He proposed
+# this instead.  This is perhaps THE hottest function in POE, and the
+# result is an approximately 4% speed improvement in his benchmarks.
+#
+# return (shift->[0] || return undef)->[ITEM_PRIORITY];
+#
+# We can do similar in a lot of places, but at what cost to
+# maintainability?
 
 sub get_next_priority {
-  # This is Ton Hospel's optimization.
-  # He measured a 4% improvement by avoiding $self.
-  return (shift->[0] || return undef)->[ITEM_PRIORITY];
+  my $self = shift;
+  return undef unless @$self;
+  return $self->[0]->[ITEM_PRIORITY];
 }
 
 ### Return the number of items currently in the queue.
 
 sub get_item_count {
-  return scalar @{$_[0]};
+  my $self = shift;
+  return scalar @$self;
 }
 
 ### Internal method to insert an item using a binary seek and splice.
@@ -458,4 +467,3 @@ and POE's licensing.
 =cut
 
 # rocco // vim: ts=2 sw=2 expandtab
-# TODO - Edit.
